pub enum ViewerMsg {
Page(PageReady),
NewJob,
JobDone,
PasswordRequired {
filename: String,
retry: bool,
},
}Expand description
Message from interpreter to viewer via the relay thread.
Variants
Page(PageReady)
A page is ready for display.
NewJob
A new job is starting — clear accumulated pages.
JobDone
Current job is finished — all pages for this job have been sent.
PasswordRequired
An encrypted PDF needs a password. The viewer should prompt the
user and send the response via ViewerEnd::password_response_sender.
retry is true when a previous password was rejected.